==> dialob-session-engine-2.1.16-sources.jar: io/dialob/session/engine/program/model/ProgramVisitor.java <==
/*
 * Copyright © 2015 - 2021 ReSys (info@dialob.io)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.dialob.session.engine.program.model;

import javax.annotation.Nonnull;
import java.util.Optional;

public interface ProgramVisitor {

  @FunctionalInterface
  interface ItemVisitor {

    void visitItem(@Nonnull Item item);

    default void end() {
    }
  }

  @FunctionalInterface
  interface ValueSetVisitor {
    void visitValueSet(@Nonnull ValueSet valueSet);

    default void end() {
    }
  }

  @FunctionalInterface
  interface ErrorVisitor {
    void visitError(@Nonnull Error error);

    default void end() {
    }
  }

  default void startProgram(@Nonnull Program program) {
  }

  default Optional<ItemVisitor> visitItems() {
    return Optional.empty();
  }

  default Optional<ValueSetVisitor> visitValueSets() {
    return Optional.empty();
  }

  default Optional<ErrorVisitor> visitErrors() {
    return Optional.empty();
  }

  default void end() {
  }

}

==> dialob-session-engine-2.3.0-sources.jar: io/dialob/session/engine/program/model/ProgramVisitor.java <==
/*
 * Copyright © 2015 - 2025 ReSys (info@dialob.io)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.dialob.session.engine.program.model;

import edu.umd.cs.findbugs.annotations.NonNull;

import java.util.Optional;

public interface ProgramVisitor {

  @FunctionalInterface
  interface ItemVisitor {

    void visitItem(@NonNull Item item);

    default void end() {
    }
  }

  @FunctionalInterface
  interface ValueSetVisitor {
    void visitValueSet(@NonNull ValueSet valueSet);

    default void end() {
    }
  }

  @FunctionalInterface
  interface ErrorVisitor {
    void visitError(@NonNull Error error);

    default void end() {
    }
  }

  default void startProgram(@NonNull Program program) {
  }

  default Optional<ItemVisitor> visitItems() {
    return Optional.empty();
  }

  default Optional<ValueSetVisitor> visitValueSets() {
    return Optional.empty();
  }

  default Optional<ErrorVisitor> visitErrors() {
    return Optional.empty();
  }

  default void end() {
  }

}
